@@ -18,9 +18,10 @@ import os
 import warnings
 
 import click
-
-from rqsdk.const import TAG_MAP, VERSION_MAP
-from rqsdk.license_helper import format_rqdatac_uri, license_console, print_rqdata_info, set_to_environ, verify_uri
+from rqsdk.const import DEFAULT_BUNDLE_PATH, TAG_MAP, VERSION_MAP
+from rqsdk.license_helper import format_rqdatac_uri, get_rqdata_info, license_console, print_license_info, \
+    set_to_environ
+from rqsdk.proxy_helper import verify_proxy_uri
 from rqsdk.script_update import pip_install
 
 
@@ -35,29 +36,111 @@ def cli():
 
 
 @cli.command()
-@click.argument('rqdatac_uri', default="", nargs=1)
-def license(rqdatac_uri):
-    """配置 license 到环境变量"""
-    warnings.filterwarnings("ignore", message="rqdatac is already inited. Settings will be changed.")
+@click.argument('command', default="", nargs=1)
+@click.option('-l', '--license', default="", help="rqdatac_uri", hidden=True)
+def license(command, license):
+    """
+    配置 license 到环境变量
 
-    if rqdatac_uri == "info":
-        uri = os.environ.get('RQDATAC2_CONF')
-        if uri is None:
-            click.echo("当前环境没有配置 license ")
+    \b
+    rqsdk license 进入交互模式
+    rqsdk license info 查看当前环境中的license信息
+    rqsdk license -l [LICENSE]|[USERNAME:PASSWORD] 配置当前环境的license
+    例如: rqsdk license -l 13888888888:xxxxxxx
+          rqsdk license -l license_key
+    """
+    warnings.filterwarnings("ignore", message="rqdatac is already inited. Settings will be changed.")
+    # 查看license
+    if command == "info":
+        # RQSDK_LICENSE优先
+        uri_license = os.environ.get('RQSDK_LICENSE') or os.environ.get('RQDATAC2_CONF')
+        if uri_license:
+            print_license_info(uri_license)
         else:
-            print_rqdata_info(uri)
+            click.echo("当前环境没有配置 license ")
+            click.echo("输入 rqsdk license --help 查看帮助信息")
         return
 
-    elif rqdatac_uri != "":
-        rqdatac_uri = format_rqdatac_uri(rqdatac_uri)
-        if verify_uri(rqdatac_uri):
-            print_rqdata_info(rqdatac_uri)
-            set_to_environ(rqdatac_uri)
+    # 设置license
+    if license:
+        uri_license = format_rqdatac_uri(license)
+        uri_rqdata = os.environ.get('RQDATAC2_CONF') or uri_license
+        if print_license_info(uri_license, uri_rqdata):
+            set_to_environ(["RQSDK_LICENSE", "RQDATAC_CONF"], uri_license)
+        return
+
+    # 查看+设置license
+    license_console()
+    return
+
+
+@cli.command()
+@click.option('--rqdatac', default="", nargs=1)
+@click.option('--show', is_flag=True, default=False)
+def config(rqdatac, show):
+    """单独配置rqdatac地址
+
+    \b
+    rqsdk config --rqdatac tcp  rqdatac_uri 单独配置rqdata鉴权
+    rqsdk config --show 显示单独配置的鉴权 uri
+    rqdatac_uri 格式应为 user:password 或者 tcp://user:password@ip:port
+    """
+    if show:
+        uri = os.environ.get('RQDATAC2_CONF')
+        if uri:
+            click.echo("rqdatac:{}".format(uri))
+    if rqdatac:
+        rqdatac_uri = format_rqdatac_uri(rqdatac)
+        if get_rqdata_info(rqdatac_uri):
+            set_to_environ(["RQDATAC2_CONF"], rqdatac_uri)
+
+
+@cli.command()
+@click.argument('proxy_uri', default="", nargs=1)
+def proxy(proxy_uri):
+    """配置 代理 到环境变量
+
+    \b
+    rqsdk proxy info 显示环境变量
+    rqsdk proxy 进入交互环境
+    """
+    if proxy_uri == "info":
+        uri = os.environ.get('RQSDK_PROXY')
+        if uri is None:
+            click.echo("当前环境未配置代理")
+        else:
+            click.echo("当前环境代理：{}".format(uri))
+        return
+
+    elif proxy_uri != "":
+        if verify_proxy_uri(proxy_uri):
+            proxy_list = ['RQDATAC_PROXY', 'RQALPHA_PROXY', 'RQSDK_PROXY']
+            set_to_environ(proxy_list, proxy_uri)
+            for row in proxy_list:
+                os.environ[row] = proxy_uri
             return
 
-    rqdatac_uri = rqdatac_uri or os.environ.get('RQDATAC2_CONF')
-    license_console(rqdatac_uri)
-    return
+    proxy_uri = proxy_uri or os.environ.get('RQSDK_PROXY')
+    while True:
+        # print
+        if proxy_uri:
+            click.echo("当前环境代理：{}".format(proxy_uri))
+        else:
+            click.echo("当前环境未配置代理")
+        # input
+        click.echo('输入 URL 以设置代理（支持 http、sock4、sock5 代理，URL 形如：http://user:password@host:port）')
+        click.echo('输入 [clear] 删除代理，否则请按 Enter 键退出')
+        proxy_uri = input()
+        if not proxy_uri:
+            return
+        if proxy_uri == "clear":
+            proxy_list = ['RQDATAC_PROXY', 'RQALPHA_PROXY', 'RQSDK_PROXY']
+            set_to_environ(proxy_list, "")
+            return
+        if verify_proxy_uri(proxy_uri):
+            proxy_list = ['RQDATAC_PROXY', 'RQALPHA_PROXY', 'RQSDK_PROXY']
+            set_to_environ(proxy_list, proxy_uri)
+            return
 
 
 @cli.command()
@@ -164,16 +247,17 @@ def version():
     for item in VERSION_MAP['rqalpha_plus']:
         try:
             package_name = item.split("==")[0]
-            _package = importlib.import_module(package_name)
-            click.echo("{}=={}".format(package_name, _package.__version__))
+            if package_name != 'rqoptimizer2':
+                _package = importlib.import_module(package_name)
+                click.echo("{}=={}".format(package_name, _package.__version__))
         except:
             pass
 
 
 @cli.command()
 @click.option(
-    '-d', '--data-bundle-path', default=os.path.expanduser('~/.rqalpha-plus'), type=click.Path(file_okay=False),
-    help="bundle 目录，默认为 ~/.rqalpha-plus"
+    '-d', '--data-bundle-path', default=DEFAULT_BUNDLE_PATH, type=click.Path(file_okay=False),
+    help="bundle 目录，默认为 {}".format(DEFAULT_BUNDLE_PATH)
 )
 @click.option(
     "--base", default=False, is_flag=True,
@@ -218,6 +302,11 @@ def update_data(data_bundle_path, base, minbar, tick, with_derivatives, concurre
     try:
         from rqalpha_plus.bundle import update_bundle_from_rqdatac
         from rqalpha_plus.bundle import update_bundle_from_exist_file
+        from rqalpha_plus.utils.scripts import check_tick
+        path = os.path.join(data_bundle_path, 'bundle')
+        if os.path.exists(path):
+            check_tick(path)
+
         update_bundle_from_rqdatac(concurrency, data_bundle_path, base, minbar, tick, with_derivatives)
         if smart:
             update_bundle_from_exist_file(concurrency, data_bundle_path)
@@ -227,8 +316,8 @@ def update_data(data_bundle_path, base, minbar, tick, with_derivatives, concurre
 
 @cli.command()
 @click.option(
-    '-d', '--data-bundle-path', default=os.path.expanduser('~/.rqalpha-plus'), type=click.Path(file_okay=False),
-    help="bundle 目录，默认为 ~/.rqalpha-plus"
+    '-d', '--data-bundle-path', default=DEFAULT_BUNDLE_PATH, type=click.Path(file_okay=False),
+    help="bundle 目录，默认为 {}".format(DEFAULT_BUNDLE_PATH)
 )
 @click.option("--sample", is_flag=True, help="下载数据样例")
 @click.option('-f', '--file-path', default=None, help="指定的压缩文件包")
